@@ -1,6 +1,10 @@
 # 2021-2-6
 import zipfile, pathlib,json
 
+essay = '''   English is a internationaly language which becomes importantly for modern world.
+    In China, English is took to be a foreigh language which many student choosed to learn. They begin to studying English at a early age. They use at least one hour to learn English knowledges a day. Even kids in kindergarten have begun learning simple words. That's a good phenomenan, for English is essential nowadays.
+    In addition to, some people think English is superior than Chinese. In me opinion, though English is for great significance, but English is after all a foreign language. it is hard for people to see eye to eye. English do help us read English original works, but Chinese helps us learn a true China. Only by characters Chinese literature can send off its brilliance. Learning a country's culture, especial its classic culture, the first thing is learn its language. Because of we are Chinese, why do we give up our mother tongue and learn our owne culture through a foreign language?'''
+
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
 		while True:
