@@ -1,4 +1,4 @@
-
+# 2022.3.10
 import requests 
 from collections import	Counter, defaultdict
 
@@ -19,3 +19,9 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 		print ("likelihood ex:",e, a,b,c,d)
 		return 0
 
+def readline(infile, sepa=None):
+	with open(infile, 'r') as fp:
+		while True:
+			line = fp.readline()
+			if not line: break
+			yield line.strip().split(sepa) if sepa else line.strip()
\ No newline at end of file
